import * as pulumi from "@pulumi/pulumi";
export declare class Bastion extends pulumi.ComponentResource {
    /**
     * Returns true if the given object is an instance of Bastion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Bastion;
    /**
     * The SSH private key to access your bastion
     */
    readonly privateKey: pulumi.Output<string>;
    /**
     * The name of the Scaleset that managed the bastion instances
     */
    readonly scaleSetName: pulumi.Output<string>;
    /**
     * Create a Bastion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BastionArgs, opts?: pulumi.ComponentResourceOptions);
}
/**
 * The set of arguments for constructing a Bastion resource.
 */
export interface BastionArgs {
    /**
     * The Azure instance SKU to use for the bastion.
     */
    instanceSlu?: pulumi.Input<string>;
    /**
     * The Azure region you're using.
     */
    location: pulumi.Input<string>;
    /**
     * The Azure resource group to create the bastion in.
     */
    resourceGroupName: pulumi.Input<string>;
    /**
     * The route you'd like to advertise via tailscale.
     */
    route: pulumi.Input<string>;
    /**
     * The subnet Ids to launch instances in.
     */
    subnetId: pulumi.Input<string>;
}
